@@ -314,10 +314,11 @@ class RDYFile:
                 self._synchronize()
         elif self.sync_method == "ntp_time":
             if len(self.measurements[NTPDatetimeSeries]) > 0 and options['SYNC_USING_NTP_DATETIME_SERIES']:
+                logger.debug(f'({self.filename}) Using NTPDatetimeSeries for syncing')
                 # This uses the median value for syncing
                 ntp = self.measurements[NTPDatetimeSeries]
-
-                dt = (ntp.time - ntp.ntp_datetime) / np.timedelta64(1, 'ms')
+                ntp_ns = (ntp.ntp_datetime - ntp.ntp_datetime[0]) / np.timedelta64(1, 'ns')
+                dt = (ntp._time - ntp_ns)
                 idx = (np.abs(dt - np.median(dt))).argmin()
 
                 for m in self.measurements.values():
