@@ -289,7 +289,7 @@ class OSM:
 
         for railway_type in tqdm(self.desired_railway_types, desc="Railway Types"):
             # Create Overpass queries and try downloading them
-            logger.debug("  Querying data for railway type: %s" % railway_type)
+            logger.debug("Querying data for railway type: %s" % railway_type)
 
             trk_query, rou_query = self._create_query(bbox=b,
                                                       railway_type=railway_type,
@@ -364,7 +364,7 @@ class OSM:
 
     def _download_track_data(self, overpass_instances=None):
         logger.info("Start downloading track data.")
-        for i, b in tqdm(enumerate(self.bbox), desc="Bounding Boxes"):
+        for i, b in enumerate(tqdm(self.bbox, desc="Bounding Boxes")):
             logger.debug("Querying data for bounding box (%d / %d): %s" % (i + 1, len(self.bbox), str(b)))
             self._query_data_for_bbox(b, overpass_instances=overpass_instances)
         logger.info("Finished downloading track data.")
